"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNextCheckboxState = exports.CONTROLLED_TABLE_NONE_SELECTED = exports.CONTROLLED_TABLE_SELECTED_ALL = void 0;
/**
 * @internal
 */
exports.CONTROLLED_TABLE_SELECTED_ALL = '__CONTROLLED_TABLE_SELECTED_ALL__';
/**
 * @internal
 */
exports.CONTROLLED_TABLE_NONE_SELECTED = '__CONTROLLED_TABLE_NONE_SELECTED__';
/**
 * @internal
 *
 * This function is used to get the next checkbox state. This function is separated
 * because the checkbox state is used in both `TableHeader` and `TableBody` components.
 */
function getNextCheckboxState({ checkboxState, checkboxProp, data, filteredDataLength, idProp, type }) {
    const nextCheckboxState = Object.assign({}, checkboxState[checkboxProp]);
    if (data === exports.CONTROLLED_TABLE_SELECTED_ALL) {
        nextCheckboxState.state = 'all-selected';
        return nextCheckboxState;
    }
    if (data === exports.CONTROLLED_TABLE_NONE_SELECTED) {
        nextCheckboxState.state = 'none-selected';
        return nextCheckboxState;
    }
    // None selected.
    // This one is easy, just add all of them.
    if (checkboxState[checkboxProp].state === 'none-selected') {
        const newSet = new Set();
        if (Array.isArray(data)) {
            for (const row of data) {
                newSet.add(row[idProp]);
            }
        }
        else {
            newSet.add(data[idProp]);
        }
        nextCheckboxState.selected = newSet;
        nextCheckboxState.state =
            newSet.size === filteredDataLength ? 'all-selected' : 'some-selected';
        return nextCheckboxState;
    }
    // Some, or all selected.
    // This is a bit tricky, because we need to consider whether we want to add or remove.
    const newSet = new Set(checkboxState[checkboxProp].selected);
    if (Array.isArray(data)) {
        for (const row of data) {
            const value = row[idProp];
            addOrRemoveFromSet(newSet, value, type);
        }
    }
    else {
        addOrRemoveFromSet(newSet, data[idProp], type);
    }
    nextCheckboxState.selected = newSet;
    nextCheckboxState.state =
        newSet.size === 0
            ? 'none-selected'
            : newSet.size === filteredDataLength
                ? 'all-selected'
                : 'some-selected';
    return nextCheckboxState;
}
exports.getNextCheckboxState = getNextCheckboxState;
// Helper functions.
function addOrRemoveFromSet(set, value, type) {
    // Depending on the checkbox state, delete or add.
    if (type === 'remove') {
        set.delete(value);
    }
    else {
        set.add(value);
    }
}
